rnalysis.filtering.DESeqFilter.filter\_by\_bigtable\_group
==========================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: DESeqFilter.filter_by_bigtable_group